import React from "react"
import { Directory, File } from "../generated/graphql"
import FileBrowserElement from "./FileBrowserElement"

interface Props{
    directorys: Directory[]
    files: File[]
    
	onFileContext?: (event: React.MouseEvent, id: string)=>void
    onDirContext?: (event: React.MouseEvent, path: string)=>void
    onFileClick?: (event: React.MouseEvent,id: string)=>void
    onDirClick?: (event: React.MouseEvent,path: string)=>void

	editId:  string
	editEnable: boolean
	onRenameDone?: (id: string, changed: boolean, newName: string)=>void
}

const FileBrowserList: React.FC<Props> = (props) => {
	return <>
		<table className="w-full">
			<thead className="border-b-2 dark:border-gray-900">
				<tr>
					<th className="text-left">Name</th>
					<th className="text-left">Last Modified</th>
					<th className="text-left">Size</th>
				</tr>
			</thead>
			<tbody className="divide-y dark:divide-gray-900">
				{ props.directorys.map(v => (<FileBrowserElement
					key={v.id}
					dir={v}
					onClick={(e,dir)=>{
						props.onDirClick?.(e,dir.id)
					}}
					onContextMenu={(e)=>{
						props.onDirContext?.(e,v.id)
					}}

					edit={props.editEnable && (v.id === props.editId)}

					onRename={(newName)=>{
						if (v.name != newName){
							props.onRenameDone?.(v.id,true,newName)
						}else{
							props.onRenameDone?.(v.id,false,newName)
						}
					}}

					onCancleRename={()=>props.onRenameDone?.(v.id,false,"")}
				/>))}
								
				{ props.files.map(v => (<FileBrowserElement 
					key={v.id}
					file={v}
					onClick={(e,file)=>{
						props.onFileClick?.(e,file.id)
					}}
					onContextMenu={(e)=>{
						props.onFileContext?.(e,v.id)
					}}

					edit={props.editEnable && (v.id === props.editId)}

					onRename={(newName)=>{
						if (v.name != newName){
							props.onRenameDone?.(v.id,true,newName)
						}else{
							props.onRenameDone?.(v.id,false,newName)
						}
					}}

					onCancleRename={()=>props.onRenameDone?.(v.id,false,"")}
				/>))}
			</tbody>
		</table>
	</>
}

export default FileBrowserList
